#
# spec file for package flux2-cli
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

%define repo_name flux2

# check these versions on updates
# see flux2/manifests/bases/*/kustomization.yaml
%define helm_controller_version             v0.37.2
%define image_automation_controller_version v0.37.0
%define image_reflector_controller_version  v0.31.1
%define kustomize_controller_version        v1.2.1
%define notification_controller_version     v1.2.3
%define source_controller_version           v1.2.3

Name:           flux2-cli
Version:        2.2.2
Release:        1.1
Summary:        CLI for Flux2CD
License:        Apache-2.0
URL:            https://github.com/fluxcd/flux2
Source:         %{repo_name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source11:       helm-controller.crds.yaml
Source12:       helm-controller.deployment.yaml
Source13:       image-automation-controller.crds.yaml
Source14:       image-automation-controller.deployment.yaml
Source15:       image-reflector-controller.crds.yaml
Source16:       image-reflector-controller.deployment.yaml
Source17:       kustomize-controller.crds.yaml
Source18:       kustomize-controller.deployment.yaml
Source19:       notification-controller.crds.yaml
Source20:       notification-controller.deployment.yaml
Source21:       source-controller.crds.yaml
Source22:       source-controller.deployment.yaml
Source101:      Packaging_README.md
Source102:      download_yaml.sh
BuildRequires:  git-core
BuildRequires:  go >= 1.20
BuildRequires:  helm
BuildRequires:  kustomize

%description
Flux is a tool for keeping Kubernetes clusters in sync with sources of configuration (like Git repositories and OCI artifacts), and automating updates to configuration when there is new code to deploy.

Flux version 2 ("v2") is built from the ground up to use Kubernetes' API extension system, and to integrate with Prometheus and other core components of the Kubernetes ecosystem. In version 2, Flux supports multi-tenancy and support for syncing an arbitrary number of Git repositories, among other long-requested features.

Flux v2 is constructed with the GitOps Toolkit, a set of composable APIs and specialized tools for building Continuous Delivery on top of Kubernetes.

Flux is a Cloud Native Computing Foundation (CNCF) project, used in production by various organisations and cloud providers.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1 -n %{repo_name}-%{version}

%build
cp %{SOURCE11} ./manifests/bases/helm-controller/
cp %{SOURCE12} ./manifests/bases/helm-controller/
sed -i 's_https://github.com/fluxcd/helm-controller/releases/download/%{helm_controller_version}/__g' manifests/bases/helm-controller/kustomization.yaml
cat manifests/bases/helm-controller/kustomization.yaml

cp %{SOURCE13} ./manifests/bases/image-automation-controller/
cp %{SOURCE14} ./manifests/bases/image-automation-controller/
sed -i 's_https://github.com/fluxcd/image-automation-controller/releases/download/%{image_automation_controller_version}/__g' manifests/bases/image-automation-controller/kustomization.yaml
cat manifests/bases/image-automation-controller/kustomization.yaml

cp %{SOURCE15} ./manifests/bases/image-reflector-controller/
cp %{SOURCE16} ./manifests/bases/image-reflector-controller/
sed -i 's_https://github.com/fluxcd/image-reflector-controller/releases/download/%{image_reflector_controller_version}/__g' manifests/bases/image-reflector-controller/kustomization.yaml
cat manifests/bases/image-reflector-controller/kustomization.yaml

cp %{SOURCE17} ./manifests/bases/kustomize-controller/
cp %{SOURCE18} ./manifests/bases/kustomize-controller/
sed -i 's_https://github.com/fluxcd/kustomize-controller/releases/download/%{kustomize_controller_version}/__g' manifests/bases/kustomize-controller/kustomization.yaml
cat manifests/bases/kustomize-controller/kustomization.yaml

cp %{SOURCE19} ./manifests/bases/notification-controller/
cp %{SOURCE20} ./manifests/bases/notification-controller/
sed -i 's_https://github.com/fluxcd/notification-controller/releases/download/%{notification_controller_version}/__g' manifests/bases/notification-controller/kustomization.yaml
cat manifests/bases/notification-controller/kustomization.yaml

cp %{SOURCE21} ./manifests/bases/source-controller/
cp %{SOURCE22} ./manifests/bases/source-controller/
sed -i 's_https://github.com/fluxcd/source-controller/releases/download/%{source_controller_version}/__g' manifests/bases/source-controller/kustomization.yaml
cat manifests/bases/source-controller/kustomization.yaml

./manifests/scripts/bundle.sh

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-s -w -X main.VERSION=%{version}" \
   -o bin/flux ./cmd/flux

%install
# Install the binary.
install -D -m 0755 bin/flux "%{buildroot}/%{_bindir}/flux"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions
%{buildroot}/%{_bindir}/flux completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d
%{buildroot}/%{_bindir}/flux completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/flux completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/flux.fish

%files
%doc README.md
%license LICENSE
%{_bindir}/flux

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/flux.fish

%changelog
* Wed Dec 20 2023 rombert@apache.org
- Update to version 2.2.2:
  * Update helm-controller to v0.37.2 in tests
  * Update toolkit components
  * Fix typo in bootstrap_plain_git.go
  * build(deps): bump the ci group with 3 updates
  * build(deps): bump golang.org/x/crypto from 0.16.0 to 0.17.0
  * build(deps): bump golang.org/x/crypto in /tests/integration
  * build(deps): bump golang.org/x/crypto in /tests/azure
* Fri Dec 15 2023 kastl@b1-systems.de
- Update to version 2.2.1:
  Flux v2.2.1 is a patch release that comes with fixes to API
  backwards compatibility. Users are encouraged to upgrade for the
  best experience.
  * tests: update API dependencies
  * Update toolkit components
  * Run conformance tests for Kubernetes v1.29.0
  * Remove duplicate part of the reconcile hr --reset help message
  * Properly detect unsupported API errors
* Tue Dec 12 2023 kastl@b1-systems.de
- Update to version 2.2.0:
  * Drop support for Kubernetes EOL versions
  * updating go-git-providers to v0.19.2
  * Correct "sync" to "component" in log lines
  * Update alpine and kubectl in flux-cli image
  * Use `IsObjectNamespaced` from controller-runtime
  * Update tests to `HelmRelease` v2beta2
  * Adapt tree command to `HelmRelease` v2beta2
  * Update `HelmRelease` to v2beta2
  * Add force and reset flags to `flux reconcile hr`
  * Update HelmRelease golden file with new message
  * Update toolkit components
  * Update Git dependencies
  * build(deps): bump the ci group with 4 updates
  * Update Helm OCI RFC - static HelmRepository design
  * tests/int: do not wait for static objects
  * Update all the references of NC v1beta2 to v1beta3
  * non-reconciliable & readiness of static objects
  * check readiness using kstatus
  * bootstrap: provide better error message on timeout
  * Update toolkit components
  * Fix typos in flux bootstrap documentation
  * show cluster instance name and version in flux check and flux
    version
  * build(deps): bump the ci group with 4 updates
  * Fix flux install command so it returns an error when unexpected
    arguments are passed
  * OIDC identity matching for keyless verification
  * Update dependencies
  * make flux events work with lowercased kinds
  * fix build_artifact.go typo
  * build(deps): bump the ci group with 2 updates
  * Update `fluxcd/pkg` dependencies
  * Tweak permissions on created files
  * build(deps): bump the ci group with 2 updates
  * tests/int: Set exit code 1 on tf destroy fail
  * feat: add gitea bootstrapper
  * Display better uninstall prompt if flux is managed by a
    different tool
  * confirm before overriding installation by another manager
  * build(deps): bump github.com/docker/docker in
    /tests/integration
  * build(deps): bump github.com/docker/docker
  * build(deps): bump the ci group with 2 updates
  * build(deps): bump google.golang.org/grpc in /tests/integration
  * prevent flux install from overriding bootrapped cluster
  * build(deps): bump the ci group with 1 update
  * misc: clean up immediately and avoid delayed defer
  * misc: fix hypothetical implicit memory aliasing
  * misc: `sinceSeconds` -> `sinceDuration`
  * misc: remove unused bits of code
  * misc: address `wait.PollImmediate` deprecation
  * misc: use `errors.As` instead of type checking
  * misc: unconditional `strings.TrimPrefix`
  * misc: address `kustomize/api/filesys` deprecation
  * misc: simplify row append
  * misc: address double import
  * misc: use raw string for regex to avoid double esc
  * misc: address unnecessary use of `fmt.Sprintf`
  * misc: handle undhandled error
  * misc: address `strings.Title` deprecation
  * Add CLI flag for OCIRepo verify secret
  * Print artifact source and revision only when available
  * Upgrade github.com/fluxcd/pkg/oci
  * fix: only wait for changeset if the result is not empty
  * Update go-git-providers to v0.19.1
  * e2e: Update Go dependencies
  * build(deps): bump golang.org/x/net from 0.15.0 to 0.17.0
  * Update toolkit components
  * build(deps): bump the ci group with 1 update
  * Add badge for SLSA Level 3
  * build(deps): bump the ci group with 1 update
  * Improve AUR package templates
  - remove armv6h #4224
  - unique source name #4224
  - improve `pkgver/_srcver` #4224
  - fix source name in .SRCINFO
  * tests/azure: update controller dependencies
  * Update toolkit components
  * update description of kubeconfig flags
  * build(deps): bump the ci group with 4 updates
  * Upgrade github.com/fluxcd/pkg/{git,git/gogit}
  * chore: remove support armv6h for aur package #4224
  * build(deps): bump the ci group with 3 updates
  * build(deps): bump github.com/cyphar/filepath-securejoin
  * build(deps): bump github.com/cyphar/filepath-securejoin in
    /tests/azure
  * build(deps): bump the ci group with 4 updates
  * build(deps): bump github.com/docker/distribution in
    /tests/integration
  * build(deps): bump github.com/docker/docker in
    /tests/integration
  * workflows/e2e-azure: Disable new azure job
  * workflows/e2e-gcp: Fix secret variable typo
  * instructions for test user in Azure DevOps and GCP source repo
  * tests/int: Separate ssh key names for Azure & GCP
  * add workflow for gcp
  * tests/int: Add IAM setup automation docs and misc fixes
  * make tests for notifications provider agnostic
  * Add terraform files and config for GCP
  * Add refactored e2e tests
  * Add 2.1.x backport label
  * Fix links to fluxcd.io
  * build(deps): bump the ci group with 2 updates
* Fri Oct 13 2023 kastl@b1-systems.de
- Update to version 2.1.2:
  * Print artifact source and revision only when available
  * Upgrade github.com/fluxcd/pkg/oci
  * fix: only wait for changeset if the result is not empty
  * Update go-git-providers to v0.19.1
  * build(deps): bump golang.org/x/net from 0.15.0 to 0.17.0
  * Update toolkit components
* Tue Sep 19 2023 kastl@b1-systems.de
- Update to version 2.1.1:
  * Improve AUR package templates
  - remove armv6h #4224
  - unique source name #4224
  - improve pkgver/_srcver #4224
  - fix source name in .SRCINFO
  * chore: remove support armv6h for aur package #4224
  * tests/azure: update controller dependencies
  * Update toolkit components
  * update description of kubeconfig flags
  * Upgrade github.com/fluxcd/pkg/{git,git/gogit}
  * build(deps): bump the ci group with 2 updates
* Thu Aug 24 2023 rombert@apache.org
- Update to version 2.1.0:
  * Add monitoring configuration deprecation notice
  * tests/azure: update dependencies
  * Update dependencies
  * Update toolkit components
  * modify `flux create secret tls` to create secrets of type TLS
  * add deprecation warning per secret key field and constant
  * add flag `--ca-crt-file` to `flux create secret git`
  * deprecate TLS flags for flux create secret helm
  * add support for Kubernetes TLS keys for `flux create secret tls`
  * fix autocompletion for helm chart
  * manifestgen/install: use clean default HTTP client
  * cmd/events: handle error value
  * Fix controller version info
  * Set min value for the `--ssh-rsa-bits` flag
  * ci: disable fail-fast for ARM end-to-end
  * cmd: address typo in end-to-end tests
  * build: update securejoin dependency
  * build(deps): bump the ci group with 2 updates
  * e2e: Add Kubernetes v1.28.0 to conformance tests
  * build(deps): bump the ci group with 2 updates
  * ci: enable security-and-quality CodeQL query
  * monitoring: add Sources Stats panels
  * monitoring: add OCIRepository in cluster dashboard panels
  * disable e2e test
  * Fix selection of kustomization resource from multi doc yaml
  * Set Kubernetes min version to 1.25
  * build(deps): bump the ci group with 2 updates
  * Update dependencies - bump the APIs packages in tests - bump golang crypto and term to latest
  * action: support `openssl` and `sha256sum`
  * Take into account the server-side inventory for local diff
  * action: re-allow configuration of non-default token
  * Update toolkit components
  * docs: Link to the Flux GitHub Action documentation
  * ci: add workflow to test action
  * action: rewrite action to use `$RUNNER_TOOL_CACHE`
  * ci: release: extract the image tag from GITHUB_REF
  * ci: backport: set write permissions
  * ci: release: disable interpretation backslash esc
* Tue Jul 11 2023 kastl@b1-systems.de
- Update to version 2.0.1:
  * Update dependencies - bump the APIs packages in tests - bump
    golang crypto and term to latest
  * Take into account the server-side inventory for local diff
  * Update toolkit components
  * ci: release: extract the image tag from GITHUB_REF
  * ci: backport: set write permissions
  * ci: release: disable interpretation backslash esc
* Wed Jul  5 2023 kastl@b1-systems.de
- Update to version 2.0.0:
  * Bump kubectl to v1.27.3
  * Update dependencies
  - k8s.io/* v0.27.3
  - github.com/fluxcd/go-git-providers v0.18.0
  - github.com/fluxcd/pkg/git v0.12.3
  - github.com/fluxcd/pkg/oci v0.28.0
  - github.com/fluxcd/pkg/runtime v0.40.0
  - github.com/fluxcd/pkg/ssa v0.28.2
  - github.com/fluxcd/pkg/ssh v0.8.0
  - github.com/homeport/dyff v1.5.8
  - golang.org/x/crypto v0.10.0
  * Update toolkit components
  * docs: link to releases spec from website
  * Run conformance tests for Kubernetes v1.27.3
  * ci: group all GH action updates under the same PR
  * ci: enable workflows for `release/**` branches
  * ci: run backport under fluxcdbot account
  * Link to release cadence from minor section
  * Address review comment section titles
  * Address release procedure review nits
  * Address various nits
  * Document various release procedures
  * Apply suggestions from code review
  * Move the release procedures to dedicated doc
  * Add SLSA provenance to release artifacts
  * Apply suggestions from code review
  * Add Flux release spec
  * Add controller release artifacts spec
  * Add API versioning spec
  * Add controller release spec
  * Add shared packages release spec
  * Cleanup internal docs
  * Annotate errors from go-git-providers
  * Update go-git to unreleased v5.8.0
  * build(deps): bump docker/setup-buildx-action from 2.7.0 to
    2.8.0
  * build(deps): bump sigstore/cosign-installer from 3.1.0 to 3.1.1
  * Declaratively define (and sync) labels
  * Add backport GitHub Action workflow
  * Add examples for resuming/suspending multiple objects
  * Add support for passing multiple objects to suspend/resume
    commands
  * Set minimum supported version to Kubernetes 1.24.0
  * Fix the `flux push` example for ECR
  * Bump Go to 1.20 in aur deps
  * Align go.mod version with Kubernetes (Go 1.20)
  * RFC-0004: add section about proxy
  * Add SLSA3 generators to release workflow Generate SLSA level 3
    provenance attestations for the release assets and for the
    multi-arch container images.
  * build(deps): bump ossf/scorecard-action from 2.1.3 to 2.2.0
  * build(deps): bump sigstore/cosign-installer from 3.0.5 to 3.1.0
  * build(deps): bump anchore/sbom-action from 0.14.2 to 0.14.3
  * Don't log errors with missing CRDs for "get * all" commands
  * build(deps): bump docker/setup-buildx-action from 2.6.0 to
    2.7.0
  * build(deps): bump peter-evans/create-pull-request from 5.0.1 to
    5.0.2
  * build(deps): bump goreleaser/goreleaser-action from 4.2.0 to
    4.3.0
  * Use equivalent and shorter way to generate shell completions
  * fix 'patchesJson6902' is deprecated' warning
  * build(deps): bump docker/login-action from 2.1.0 to 2.2.0
  * build(deps): bump docker/setup-qemu-action from 2.1.0 to 2.2.0
  * build(deps): bump actions/checkout from 3.5.2 to 3.5.3
  * build(deps): bump docker/setup-buildx-action from 2.5.0 to
    2.6.0
  * build(deps): bump github/codeql-action from 2.3.6 to 2.13.4
  * Make `flux logs` more lenient
  * build(deps): bump github/codeql-action from 2.3.5 to 2.3.6
* Thu Jun  1 2023 kastl@b1-systems.de
- Update to version 2.0.0~rc5:
  * return clone error
  * set logger for controller runtime
  * Update github.com/fluxcd/pkg/git/gogit to v0.12.0
  * tests/azure: update dependencies
  * Update toolkit components
  * e2e: run e2e Azure tests for PRs to main if tests or wofklow
    changes
  * set controller-runtime logger to a null logger
* Thu Jun  1 2023 Robert Munteanu <rombert@apache.org>
- Include download_yaml.sh in sources
* Wed May 31 2023 Robert Munteanu <rombert@apache.org>
- Include Packaging_README.md in sources
- Bump raw_version to rc4
* Tue May 30 2023 kastl@b1-systems.de
- Update to version 2.0.0~rc4:
  * Update Git packages
  * Update toolkit components
  * Update kubectl to v1.27.2 in flux-cli image
  * Retry oci push operations
  * build(deps): bump github/codeql-action from 2.3.3 to 2.3.5
  * build(deps): bump snyk/actions
  * Fix break lines in create helmrelease and source
  * fix: support reconcile recursive source tree hr => chart =>
    repo
  * feat: add reconcile source chart command
  * Update Kubernetes to v1.27 and Kustomize to v5.0
  * build(deps): bump sigstore/cosign-installer from 3.0.3 to 3.0.5
  * build(deps): bump actions/setup-go from 4.0.0 to 4.0.1
  * build(deps): bump helm/kind-action from 1.5.0 to 1.7.0
* Mon May 22 2023 Robert Munteanu <rombert@apache.org>
- Fix fish completions
* Mon May 22 2023 rombert@apache.org
- Update to version 2.0.0-rc.3:
  * e2e: Update dependencies
  * Update toolkit components
  * Add ResourceQuota for critical pods Fixes insufficient quota
    error on GKE
  * Add OSSF Scorecard
  * build(deps): bump github.com/cloudflare/circl in /tests/azure
  * build(deps): bump github.com/cloudflare/circl from 1.3.2 to
    1.3.3
  * build(deps): bump github.com/docker/distribution
  * Update Alpine to 3.18
  * Update toolkit components
  * Add summary to Azure Alert.
  * build(deps): bump anchore/sbom-action from 0.14.1 to 0.14.2
  * Fix autocompletion for image repository reconcile
  * build(deps): bump github/codeql-action from 2.3.2 to 2.3.3
  * build(deps): bump peter-evans/create-pull-request from 5.0.0 to
    5.0.1
  * bump ggp to latest version
  * Update toolkit components
  * Set priority class to critical Flux components Mark
    source-controller, kustomize-controller and helm-controller as
    system-cluster-critical. This will reduce the chances of Flux
    controllers being evicted before other non-critical workloads.
  * Run conformance tests for Kubernetes 1.27
  * Add OCI provider option to create Helm source command
  * fix some comments
  * build(deps): bump sigstore/cosign-installer from 3.0.2 to 3.0.3
  * build(deps): bump github/codeql-action from 2.3.0 to 2.3.2
  * fix: make bootstrap work with Bitbucket Server again
  * build(deps): bump github/codeql-action from 2.2.12 to 2.3.0
  * Outdated URL
  * build(deps): bump github/codeql-action from 2.2.11 to 2.2.12
  * build(deps): bump actions/checkout from 3.5.0 to 3.5.2
  * better messaging for `pull artifact` command
  * Fix publishing pre-release versions to AUR
  * clean dir before cloning git repo
  * Add label selector flag to get cmd
  * build(deps): bump sigstore/cosign-installer from 3.0.1 to 3.0.2
  * build(deps): bump github/codeql-action from 2.2.9 to 2.2.11
  * build(deps): bump peter-evans/create-pull-request from 4.2.4 to
    5.0.0
  * Add the possibility to ignore files with build and diff ks
  * build(deps): bump github.com/docker/docker
  * Add support for .sourceignore to flux build/diff
  * Add commonMetadata to flux build/diff
  * Update dependencies
  * add a preview note for all non-bootstrap commands
  * Add /v2 suffix to module name in preparation  of 2.0.0 release
  * update azure e2e tests
  * update internal flags
  * update testdata yamls
  * Update GitRepository Receiver, and Kustomization to v1
  * ci: Run the e2e tests for the release branches
  * Update toolkit components
  * build(deps): bump github.com/docker/docker
  * build(deps): bump anchore/sbom-action from 0.13.4 to 0.14.1
  * build(deps): bump github/codeql-action from 2.2.8 to 2.2.9
  * build(deps): bump anchore/sbom-action from 0.13.3 to 0.13.4
  * build(deps): bump actions/checkout from 3.4.0 to 3.5.0
  * build(deps): bump github/codeql-action from 2.2.7 to 2.2.8
  * Add support for create source git with --commit and --ref-name
    flags
  * fix: Remove any leading and trailing whitespace from resource
    before exporting
  * build(deps): bump google.golang.org/protobuf from 1.29.0 to 1.29.1
  * Implement `--deploy-token-auth` in GitLab bootstrapping
  * Update go-git-providers to v0.15.0
  * Add retry interval option to create kustomization command
- Remove outdated step from Packaging_README.md
- Minor spec and _service changes to accomodate pre-release
  versions
* Tue Mar 28 2023 Johannes Kastl <kastl@b1-systems.de>
- bash-completion subpackage now Requires bash-completion
* Tue Mar 21 2023 kastl@b1-systems.de
- Update to version 0.41.2:
  * tests/azure: update toolkit components
  * Update toolkit components
  * build: update `actions/setup-go` in workflows
  * build(deps): bump peter-evans/create-pull-request from 4.2.3 to 4.2.4
  * build(deps): bump actions/checkout from 3.3.0 to 3.4.0
  * build(deps): bump github/codeql-action from 2.2.6 to 2.2.7
  * Create secret with bearer-token
  * build(deps): bump github/codeql-action from 2.2.5 to 2.2.6
  * build(deps): bump docker/setup-buildx-action from 2.4.1 to 2.5.0
  * build(deps): bump actions/cache from 3.2.6 to 3.3.0
* Fri Mar 10 2023 kastl@b1-systems.de
- Update to version 0.41.1:
  * Update toolkit components
  * Disable drift detection for kube-prometheus-stack webhooks
* Thu Mar  9 2023 kastl@b1-systems.de
- Update to version 0.41.0:
  * events: avoid having to keep individal kind maps
  * events: reword error messages
  * events: prevent defer in loop
  * events: make `--for` case insensitive for kinds
  * events: use constants for supported Flux kinds
  * Add `flux events` command
  * diff: update Action references to typed Action
  * Update dependencies
  * ci: Use latest available images of kindest/node
  * tests/azure: update dependencies
  * e2e: update podinfo to version with newer APIs
  * build: update Kubernetes versions in e2e workflows
  * build: update scan workflow
  * build: update update workflow
  * build: update e2e{-*} workflows
  * build: update release workflow
  * build: update cache keys to reflect Go 1.20
  * Update `kubectl` in `Dockerfile` to v1.26.2
  * Update Go to 1.20
  * Update toolkit components
  * Replace `helmv2.KubeConfig` with `meta.KubeConfig`
  * Update helm-controller to v0.31.0
  * Allow custom annotations to be set when pushing OCI artifacts
  * Update dependencies
  * tests/azure: update dependencies
  * Update toolkit components
  * build(deps): bump actions/cache from 3.2.5 to 3.2.6
  * build(deps): bump github/codeql-action from 2.2.4 to 2.2.5
* Tue Feb 28 2023 Johannes Kastl <kastl@b1-systems.de>
- new package flux2-cli
